@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 
 
+import json
+
+
 class User(object):
     def __init__(self,
                  id,
@@ -18,3 +21,15 @@ class User(object):
                     first_name=data.get('first_name', None),
                     last_name=data.get('last_name', None),
                     username=data.get('username', None))
+
+    def to_json(self):
+        json_data = {'id': self.id,
+                     'first_name': self.first_name}
+        if self.last_name:
+            json_data['last_name'] = self.last_name
+        if self.username:
+            json_data['username'] = self.username
+        return json.dumps(json_data)
+
+    def __str__(self):
+        return self.to_json()
