@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 
 
+import json
+
+
 class Video(object):
     def __init__(self,
                  file_id,
@@ -36,3 +39,20 @@ class Video(object):
                      mime_type=data.get('mime_type', None),
                      file_size=data.get('file_size', None),
                      caption=data.get('caption', None))
+
+    def to_json(self):
+        json_data = {'file_id': self.file_id,
+                     'width': self.width,
+                     'height': self.height,
+                     'duration': self.duration,
+                     'thumb': self.thumb.to_json()}
+        if self.mime_type:
+            json_data['mime_type'] = self.mime_type
+        if self.file_size:
+            json_data['file_size'] = self.file_size
+        if self.caption:
+            json_data['caption'] = self.caption
+        return json.dumps(json_data)
+
+    def __str__(self):
+        return self.to_json()
